blogger_theme library

Classes

a<A, B>
The <a> HTML element (or anchor element), with its href attribute, creates a hyperlink to web pages, files, email addresses, locations in the same page, or anything else a URL can address.
Amp3dGltf
Renders 3D glTF models directly in the web browser.
Amp3qPlayer
Embeds videos from 3Q SDN.
AmpAccess
Handles content subscription paywalls and user access.
AmpAccessFewcents
Integrates paywall systems from Fewcents platform.
AmpAccessLaterpay
Integrates paywalls with the LaterPay platform.
AmpAccessPoool
Integrates paywalls from Poool.
AmpAccessScroll
Integrates paywalls from Scroll membership.
AmpAccordion
An AMP accordion component for collapsible sections of content.
AmpActionMacro
Creates reusable actions inside AMP pages.
AmpAd
An AMP component to embed advertisements.
AmpAddthis
An AMP component to integrate AddThis social tools.
AmpAdExit
Provides customizable behavior for ad exits in AMPHTML ads.
AmpAnalytics
An AMP component to capture analytics and tracking data.
AmpAnim
An AMP component for displaying animated images (e.g. GIFs).
AmpAnimation
An AMP component to declare complex visual animations.
AmpApesterMedia
Integrates interactive Apester media cards.
AmpAppBanner
Prompts users to download your mobile app.
AmpAudio
An AMP audio component replacing the HTML5 audio tag.
AmpAutoAds
Dynamically and automatically inserts advertisements into an AMP page.
AmpAutocomplete
An AMP auto-complete input field.
AmpBaseCarousel
A newer AMP carousel component.
AmpBeopinion
Embeds interactive polls or widgets from BeOpinion.
AmpBodymovinAnimation
Displays Adobe After Effects (Lottie) JSON animations.
AmpBoilerplate
The required AMP boilerplate styles.
AmpBridPlayer
Embeds a Brid.tv video player.
AmpBrightcove
An AMP component to embed Brightcove videos.
AmpBysideContent
Integrates dynamic content from the BySide service.
AmpCallTracking
Dynamically replaces phone numbers in links to enable call tracking.
AmpCanonical
Standard AMP Canonical Link tag.
AmpCarousel
An AMP carousel for displaying multiple content blocks along a horizontal axis.
AmpCharset
Standard AMP Charset Meta tag.
AmpConnatixPlayer
Embeds a cloud-hosted Connatix Video Player.
AmpConsent
An AMP component to manage cookie and storage consent.
AmpDailymotion
An AMP component to embed DailyMotion videos.
AmpDateCountdown
Displays a countdown sequence to a specified date.
AmpDateDisplay
An AMP date display component to format dates on the client side.
AmpDatePicker
An AMP date picker calendar component.
AmpDelightPlayer
Embeds a cloud-hosted Delight Video Player.
AmpDynamicCssClasses
Adds several dynamic CSS class names onto the <body> element.
AmpEmbedlyCard
Displays an Embedly media card.
AmpExperiment
Used to conduct user experience (A/B testing) experiments on AMP pages.
AmpExtensionScript
Loads an AMP custom element extension script dynamically.
AmpFacebook
An AMP component to embed Facebook content.
AmpFacebookComments
An AMP component to embed Facebook Comments.
AmpFacebookLike
An AMP component to embed a Facebook Like button.
AmpFacebookPage
An AMP component to embed Facebook Pages.
AmpFitText
An AMP fit-text component to automatically scale text within bounds.
AmpFont
Triggers and monitors the loading of custom fonts.
AmpForm
An AMP helper representing forms in AMP HTML.
AmpFxCollection
An AMP helper to easily apply visual effects (like parallax or fade).
AmpFxFlyingCarpet
An AMP parallax wrapper that behaves like a flying carpet.
AmpGeo
An AMP geo-location utility component.
AmpGfycat
An AMP component to embed Gfycat animations.
AmpGist
Embeds a GitHub Gist securely via an iframe.
AmpGoogleDocumentEmbed
Embeds a Google Document, Sheet, Slide, or Form securely.
AmpGoogleReadAloudPlayer
Embeds the Google Read Aloud speech player.
AmpGwdAnimation
Integrates animations created using Google Web Designer (GWD).
AmpHtml
An AMP HTML root helper component.
AmpHulu
An AMP component to embed Hulu videos.
AmpIframe
An AMP iframe component for embedding third-party content securely.
AmpIframely
Displays Iframely-powered rich media embeds.
AmpImageLightbox
An AMP image lightbox component specifically for images.
AmpImageSlider
Creates a side-by-side visual comparison of two images.
AmpImaVideo
Displays video ads utilizing the Google Interactive Media Ads (IMA) SDK.
AmpImg
An AMP image component replacing the standard HTML img tag.
AmpImgur
Embeds a secure Imgur image or gallery.
AmpInlineGallery
Shows multiple images along a horizontal axis for tap navigation.
AmpInputmask
Provides input masking capabilities inside form fields.
AmpInstagram
An AMP component to embed Instagram posts.
AmpInstallServiceworker
An AMP component to register service workers.
AmpIzlesene
Embeds video clips from İzlesene.com.
AmpJwplayer
An AMP component to embed JW Player videos.
AmpKalturaPlayer
An AMP component to embed Kaltura Player content.
AmpLayout
A generic, multi-purpose container element that brings AMP's layout system.
AmpLightbox
An AMP lightbox component to display content in an overlay.
AmpLightboxGallery
An AMP lightbox gallery component.
AmpLinkRewriter
Dynamically rewrites target URLs on click (e.g., for affiliate linking).
AmpList
An AMP dynamic list component that fetches JSON content and renders it via a template.
AmpLiveList
An AMP live list component to implement dynamic content updates.
AmpMathml
Displays a MathML formula.
AmpMegaMenu
An interactive mega navigation menu.
AmpMegaphone
Embeds an interactive Megaphone podcast player.
AmpMinuteMediaPlayer
Embeds video players from Minute Media.
AmpMraid
An AMP component to support MRAID ads.
AmpMrowplayer
Embeds video players from MowPlayer.
AmpMustache
An AMP Mustache template wrapper (<template type="amp-mustache">).
AmpNestedMenu
An interactive multi-level dynamic dropdown menu.
AmpNextPage
An AMP next-page component to implement infinite scroll.
AmpNexxtvPlayer
Embeds media streams from the nexxOMNIA video platform.
AmpO2Player
Embeds O2 video player content.
AmpOnetapGoogle
Integrates a Google One Tap login widget.
AmpOoyalaPlayer
Embeds Ooyala video player streams.
AmpOrientationObserver
Monitors screen orientation changes to dispatch interactive events.
AmpPanZoom
Allows zooming and panning of child components.
AmpPinterest
An AMP component to embed Pinterest boards, pins, and profiles.
AmpPixel
A self-closing AMP tracking pixel component.
AmpPlaybuzz
An AMP component to embed Playbuzz content.
AmpPositionObserver
An AMP component that monitors position of elements to trigger events.
AmpPowrPlayer
Embeds video players from POWR.
AmpReachPlayer
An AMP component to embed Reach Player videos.
AmpRecaptchaInput
Appends a reCAPTCHA v3 token to AMP form submissions.
AmpRecommender
Shows personalized content recommendation blocks.
AmpRedbullPlayer
Embeds a RedBull TV video stream player.
AmpReddit
Embeds Reddit posts or comments.
AmpRender
Renders remote or inline JSON/dynamic data.
AmpRiddleQuiz
Integrates interactive quizzes and polls from Riddle.com.
AmpRuntimeScript
The required AMP runtime script.
AmpScript
Sandboxed custom JS engine running in a Web Worker.
AmpSelector
An AMP selection element for dynamic or interactive components.
AmpSidebar
An AMP sidebar component for sliding temporary navigation menus.
Automates monetizing commerce links on AMP articles with Skimlinks affiliate network.
AmpSlikeplayer
Embeds cloud-hosted Slike Video Players.
Handles affiliate routing and link conversions using Smartlinks.
AmpSocialShare
An AMP social sharing button component.
AmpSoundcloud
An AMP component to embed SoundCloud audio tracks.
AmpSpringboardPlayer
Embeds Springboard video streams.
AmpState
An AMP state container for managing client-side state in AMP pages.
AmpStickyAd
An AMP ad container that sticks to the top or bottom of the viewport.
AmpStory
An AMP Web Story container.
AmpStory360
Embeds 360 degree immersive images or videos inside Web Stories.
AmpStoryAudioSticker
An audio control sticker inside AMP Web Stories allowing unmute actions.
AmpStoryAutoAds
Dynamically and automatically inserts advertisements into an AMP Web Story.
AmpStoryAutoAnalytics
Automatically generates analytics configs for Web Stories.
AmpStoryBookend
A bookend element within an AMP Web Story.
AmpStoryCaptions
Custom video captions renderer for Web Stories.
AmpStoryCtaLayer
A layer for links and buttons inside an AMP Web Story page.
AmpStoryGridLayer
A grid layer within an AMP Web Story page.
AmpStoryInteractivePoll
An interactive poll widget inside AMP Web Story pages.
AmpStoryInteractiveQuiz
An interactive quiz widget inside AMP Web Story pages.
AmpStoryInteractiveResults
Displays interactive results matching poll/quiz selections.
AmpStoryInteractiveSlider
An interactive emoji slider inside AMP Web Story pages.
AmpStoryPage
A page within an AMP Web Story.
AmpStoryPageAttachment
An attachment layer for an individual story page that allows swiping up.
A CTA outlink button inside AMP story pages.
AmpStoryPanningMedia
Pans and zooms an image dynamically between Web Story pages.
AmpStoryPlayer
A player for embedding and playing AMP Web Stories on standard pages.
AmpStoryShopping
A shopping experience container inside AMP story pages.
AmpStorySocialShare
Renders standard social sharing buttons within Web Stories.
AmpStorySubscriptions
Configurable subscriptions experience pane inside AMP Web Story pages.
AmpStreamGallery
A highly-optimized horizontal scrolling stream gallery.
AmpSubscriptions
Implements generalized subscription protocols.
AmpSubscriptionsGoogle
Implements subscription access protocols for Subscribe with Google.
AmpTiktok
Embeds a secure TikTok video player.
AmpTimeago
An AMP relative timeago display component.
AmpTruncateText
Truncates text with an ellipsis, optionally showing an overflow/expand element.
AmpTwitter
An AMP component to embed Twitter tweets.
AmpUserNotification
An AMP component for displaying user notifications.
AmpValidator
Helper utility to run pre-compilation validation on rendered AMP theme HTML string.
AmpVideo
An AMP video component replacing the standard HTML video tag.
AmpVideoDocking
Minimizes and docks videos to a corner on page scroll.
AmpVideoIframe
Embeds video players securely within an AMP-friendly iframe wrapper.
AmpViewport
Standard AMP Viewport Meta tag.
AmpVimeo
An AMP component to embed Vimeo videos.
AmpVine
Embeds animated Vine video loops.
AmpViqeoPlayer
Embeds Viqeo video stream players.
AmpVk
Embeds Reddit-like VK posts or poll widgets.
AmpWebPush
An AMP push notifications module.
AmpWebPushWidget
Interactive subscription widget for Web Push notifications.
AmpWistiaPlayer
Embeds customized Wistia video player clips.
AmpWordpressEmbed
Embeds a WordPress post dynamically.
AmpYotpo
Embeds interactive reviews widgets from Yotpo.
AmpYoutube
An AMP component to embed YouTube videos.
article<A, B>
The <article> HTML element represents a self-contained composition in a document, page, application, or site, which is intended to be independently distributable or reusable (e.g., in syndication). Examples include: a forum post, a magazine or newspaper article, or a blog entry, a product card, a user-submitted comment, an interactive widget or gadget, or any other independent item of content.
aside<A, B>
The <aside> HTML element represents a portion of a document whose content is only indirectly related to the document's main content. Asides are frequently presented as sidebars or call-out boxes.
audio<A, B>
The
b<A, B>
The <b> HTML element is used to draw the reader's attention to the element's contents, which are not otherwise granted special importance.
BArg
Defines a b:arg attribute with either a static or expression value.
BAttr
Adds a conditional attribute entry using Blogger's b:attr tag.
BCase
Creates a case branch inside a Blogger b:switch block.
BClass
Adds a conditional CSS class via Blogger's b:class tag.
BClientScript
Loads a Dart script from disk and compiles it to JavaScript, or renders an inline JavaScript block.
BComment
Emits a Blogger comment node.
BData
Writes a Blogger data: node with the provided value.
BDefault
Represents the default branch of a b:switch block.
BDefaultMarkup
Declares a default markup type within the Blogger template.
BDefaultMarkups
Container for multiple default markup declarations.
BElse
Renders an b:else branch for conditional template logic.
BElseIf
Renders a conditional b:elseif branch inside a b:if block.
BEval
Evaluates an expression and renders the result in the template.
BGroup
Groups multiple BVariable definitions for use in a Blogger skin.
BIf
Renders a conditional b:if block in Blogger templates.
BIncludable
Defines a named includable fragment for later use.
BInclude
Includes a Blogger template fragment by name.
blockquote<A, B>
The <blockquote> HTML element indicates that the enclosed text is an extended quotation. Usually, this is rendered visually by indentation. A URL for the source of the quotation may be given using the cite attribute, while a text representation of the source can be given using the <cite> element.
BloggerTheme
Root component for a complete Blogger theme.
BLoop
Renders a Blogger loop block using b:loop.
BMessage
Defines a translatable Blogger message block.
body<A, B>
The <body> HTML element represents the content of an HTML document. There can be only one <body> element in a document.
BParam
Represents a named or expression parameter for template helpers.
br<A, B>
The <br> HTML element produces a line break in text (carriage-return).
BSection
A Blogger section container, mapped to the b:section template tag.
BSkin
Builds a Blogger template skin block with optional CSS variables.
BSwitch
Renders a Blogger switch block.
BTag
Creates a dynamic HTML tag using Blogger template helper syntax.
BTemplateScript
Declares a Blogger template script dependency.
BTemplateSkin
Wraps raw CSS content in a Blogger b:template-skin block.
button<A, B>
The
BVariable
Describes a template variable for Blogger skin or configuration metadata.
BWidget
Models a Blogger widget definition in the template.
BWidgetSetting
Represents a named widget setting element.
BWidgetSettings
Marks where widget settings can be declared inside a Blogger layout.
BWith
Sets a local variable using Blogger's b:with helper.
caption<A, B>
The <caption> HTML element specifies the caption (or title) of a table, providing the table an accessible description.
circle<A, B>
The <circle> SVG element is an SVG basic shape, used to draw circles based on a center point and a radius.
code<A, B>
The <code> HTML element displays its contents styled in a fashion intended to indicate that the text is a short fragment of computer code.
col<A, B>
The <col> HTML element defines one or more columns in a column group represented by its parent <colgroup> element. The <col> element is only valid as a child of a <colgroup> element that has no span attribute defined.
colgroup<A, B>
The <colgroup> HTML element defines a group of columns within a table.
Component
A node in the Blogger theme component tree.
CustomDomComponent<A, B>
Concrete implementation of DomComponent used for custom or dynamic XML elements.
datalist<A, B>
The
dd<A, B>
The <dd> HTML element provides the description, definition, or value for the preceding term (<dt>) in a description list (<dl>).
details<A, B>
The <details> HTML element creates a disclosure widget in which information is visible only when the widget is toggled into an "open" state. A summary or label must be provided using the <summary> element.
dialog<A, B>
The <dialog> HTML element represents a dialog box or other interactive component, such as a dismissible alert, inspector, or subwindow.
div<A, B>
The <div> HTML element is the generic container for flow content. It has no effect on the content or layout until styled in some way using CSS (e.g. styling is directly applied to it, or some kind of layout model like Flexbox is applied to its parent element).
dl<A, B>
The <dl> HTML element represents a description list. The element encloses a list of groups of terms (specified using the <dt> element) and descriptions (provided by <dd> elements). Common uses for this element are to implement a glossary or to display metadata (a list of key-value pairs).
DomComponent<A, B>
A DOM-like element with a tag, attributes, and child components.
dt<A, B>
The <dt> HTML element specifies a term in a description or definition list, and as such must be used inside a <dl> element. It is usually followed by a <dd> element; however, multiple <dt> elements in a row indicate several terms that are all defined by the immediate next <dd> element.
Element
A component that produces an actual DOM element.
ellipse<A, B>
The <ellipse> element is an SVG basic shape, used to create ellipses based on a center coordinate, and both their x and y radius.
em<A, B>
The <em> HTML element marks text that has stress emphasis.
embed<A, B>
The HTML element embeds external content at the specified point in the document. This content is provided by an external application or other source of interactive content such as a browser plug-in.
fieldset<A, B>
The
figcaption<A, B>
The
figure<A, B>
The
The <footer> HTML element represents a footer for its nearest ancestor sectioning content or sectioning root element. A footer typically contains information about the author of the section, copyright data or links to related documents.
form<A, B>
The
Fragment
A wrapper for grouping components without introducing a DOM tag.
g<A, B>
The <g> SVG element is a container used to group other SVG elements.
h1<A, B>
The <h1> HTML element represents a level 1 heading. It is used to define the most important heading on the page, typically used for the main title or topic of the content.
h2<A, B>
The <h2> HTML element represents a level 2 heading. It is used to define subheadings or secondary titles within a document, providing a hierarchical structure to the content.
h3<A, B>
The <h3> HTML element represents a level 3 heading. It is used to define subheadings or tertiary titles within a document, providing further hierarchical structure to the content.
h4<A, B>
The <h4> HTML element represents a level 4 heading. It is used to define subheadings or quaternary titles within a document, providing additional hierarchical structure to the content.
h5<A, B>
The <h5> HTML element represents a level 5 heading. It is used to define subheadings or quinary titles within a document, providing further hierarchical structure to the content.
h6<A, B>
The <h6> HTML element represents a level 6 heading. It is used to define subheadings or senary titles within a document, providing the lowest level of hierarchical structure to the content.
The <head> HTML element contains machine-readable information (metadata) about the document, like its title, scripts, and style sheets.
The <header> HTML element represents introductory content, typically a group of introductory or navigational aids. It may contain some heading elements but also a logo, a search form, an author name, and other elements.
hr<A, B>
The <hr> HTML element represents a thematic break between paragraph-level elements: for example, a change of scene in a story, or a shift of topic within a section.
html<A, B>
The <html> HTML element represents the root (top-level element) of an HTML document, so it is also referred to as the root element. All other elements must be descendants of this element.
i<A, B>
The <i> HTML element represents a range of text that is set off from the normal text for some reason, such as idiomatic text or technical terms.
iframe<A, B>
The
img<A, B>
The HTML element embeds an image into the document.
input<A, B>
The HTML element is used to create interactive controls for web-based forms in order to accept data from the user; a wide variety of types of input data and control widgets are available, depending on the device and user agent.
label<A, B>
The
legend<A, B>
The
li<A, B>
The <li> HTML element is used to represent an item in a list. It must be contained in a parent element: an ordered list (<ol>), an unordered list (<ul>), or a menu (<menu>). In menus and unordered lists, list items are usually displayed using bullet points. In ordered lists, they are usually displayed with an ascending counter on the left, such as a number or letter.
line<A, B>
The <line> element is an SVG basic shape used to create a line connecting two points.
The <link> HTML element specifies relationships between the current document and an external resource. This element is most commonly used to link to stylesheets, but is also used to establish site icons (both "favicon" style icons and icons for the home screen and apps on mobile devices) among other things.
main_<A, B>
The <main> HTML element represents the dominant content of the <body> of a document. The main content area consists of content that is directly related to or expands upon the central topic of a document, or the central functionality of an application.
meta<A, B>
The <meta> HTML element represents metadata that cannot be represented by other HTML meta-related elements, like <base>, <link>, <script>, <style> or <title>.
meter<A, B>
The
The <nav> HTML element represents a section of a page whose purpose is to provide navigation links, either within the current document or to other documents. Common examples of navigation sections are menus, tables of contents, and indexes.
noscript<A, B>
The <noscript> HTML element defines alternative content to display when scripting is unavailable or unsupported.
object<A, B>
The
ol<A, B>
The <ol> HTML element represents an ordered list of items — typically rendered as a numbered list.
optgroup<A, B>
The
option<A, B>
The
output<A, B>
The
p<A, B>
The <p> HTML element represents a paragraph. Paragraphs are usually represented in visual media as blocks of text separated from adjacent blocks by blank lines and/or first-line indentation, but HTML paragraphs can be any structural grouping of related content, such as images or form fields.
path<A, B>
The <path> SVG element is the generic element to define a shape. All the basic shapes can be created with a path element.
polygon<A, B>
The <polygon> element defines a closed shape consisting of a set of connected straight line segments. The last point is connected to the first point.
polyline<A, B>
The <polyline> SVG element is an SVG basic shape that creates straight lines connecting several points. Typically a polyline is used to create open shapes as the last point doesn't have to be connected to the first point.
pre<A, B>
The <pre> HTML element represents preformatted text which is to be presented exactly as written in the HTML file. The text is typically rendered using a non-proportional, or monospaced, font. Whitespace inside this element is displayed as written.
progress<A, B>
The
RawText
A raw text node that disables XML escaping.
rect<A, B>
The <rect> element is a basic SVG shape that draws rectangles, defined by their position, width, and height. The rectangles may have their corners rounded.
s<A, B>
The <s> HTML element renders text with a strikethrough, or a line through it.
script<A, B>
The <script> HTML element is used to embed executable code or data; this is typically used to embed or refer to JavaScript code. The <script> element can also be used with other languages, such as WebGL's GLSL shader programming language and JSON.
section<A, B>
The <section> HTML element represents a generic standalone section of a document, which doesn't have a more specific semantic element to represent it. Sections should always have a heading, with very few exceptions.
select<A, B>
The
small<A, B>
The <small> HTML element represents side-comments and small print, like copyright and legal text.
source<A, B>
The HTML element specifies multiple media resources for the , the
span<A, B>
The <span> HTML element is a generic inline container for phrasing content, which does not inherently represent anything.
strong<A, B>
The <strong> HTML element indicates that its contents have strong importance, seriousness, or urgency.
style<A, B>
summary<A, B>
The <summary> HTML element specifies a summary, caption, or legend for a <details> element's disclosure box. Clicking the <summary> element toggles the state of the parent <details> element open and closed.
svg<A, B>
The <svg> element is a container that defines a new coordinate system and viewport. It is used as the outermost element of SVG documents, but it can also be used to embed an SVG fragment inside an SVG or HTML document.
table<A, B>
The <table> HTML element represents tabular data—that is, information presented in a two-dimensional table comprised of rows and columns of cells containing data.
tbody<A, B>
The <tbody> HTML element encapsulates a set of table rows (<tr> elements), indicating that they comprise the body of a table's (main) data.
td<A, B>
The <td> HTML element defines a cell of a table that contains data and may be used as a child of the <tr> element.
Text
A text node that is rendered with optional XML escaping.
textarea<A, B>
The
tfoot<A, B>
The <tfoot> HTML element encapsulates a set of table rows (<tr> elements), indicating that they comprise the foot of a table with information about the table's columns. This is usually a summary of the columns, e.g., a sum of the given numbers in a column.
th<A, B>
The <th> HTML element defines a cell as the header of a group of table cells and may be used as a child of the <tr> element. The exact nature of this group is defined by the scope and headers attributes.
thead<A, B>
The <thead> HTML element encapsulates a set of table rows (<tr> elements), indicating that they comprise the head of a table with information about the table's columns. This is usually in the form of column headers (<th> elements).
title<A, B>
The <h1> title in Nav Browser Client
tr<A, B>
The <tr> HTML element defines a row of cells in a table. The row's cells can then be established using a mix of <td> (data cell) and <th> (header cell) elements.
u<A, B>
The <u> HTML element represents a span of inline text which should be rendered in a way that indicates that it has a non-textual annotation.
ul<A, B>
The <ul> HTML element represents an unordered list of items, typically rendered as a bulleted list.
use<A, B>
The <use> element takes nodes from within the SVG document, and duplicates them elsewhere.
video<A, B>
The
wbr<A, B>
The <wbr> HTML element represents a word break opportunity—a position within text where the browser may optionally break a line.
XmlComment
Emits a raw XML comment in the rendered output.