h1<A, B> class
final
The <h1> HTML element represents a level 1 heading. It is used to define the most important heading on the page, typically used for the main title or topic of the content.
- Inheritance
-
- Object
- DomComponent<
A, B> - h1
- Available extensions
Constructors
- h1([A? first, B? second])
-
const
Properties
Methods
-
build(
) → Iterable< Component> -
Builds this component's children.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
render(
[Renderer renderer = const Renderer(), StringBuffer? sb]) → String -
Available on Component, provided by the RenderComponentExtension extension
Renders this component tree to an XML string using an optional custom Renderer. -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited