h3<A, B> class
final
The <h3> HTML element represents a level 3 heading. It is used to define subheadings or tertiary titles within a document, providing further hierarchical structure to the content.
- Inheritance
-
- Object
- DomComponent<
A, B> - h3
- Available extensions
Constructors
- h3([A? first, B? second])
-
const
Properties
Methods
-
build(
) → Iterable< Component> -
Builds this component's children.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
render(
[Renderer renderer = const Renderer(), StringBuffer? sb]) → String -
Available on Component, provided by the RenderComponentExtension extension
Renders this component tree to an XML string using an optional custom Renderer. -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited