line<A, B> class
final
The <line> element is an SVG basic shape used to create a line connecting two points.
- Inheritance
-
- Object
- DomComponent<
A, B> - line
- Available extensions
Constructors
- line([A? first, B? second])
-
const
Properties
Methods
-
build(
) → Iterable< Component> -
Builds this component's children.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
render(
[Renderer renderer = const Renderer(), StringBuffer? sb]) → String -
Available on Component, provided by the RenderComponentExtension extension
Renders this component tree to an XML string using an optional custom Renderer. -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited