object<A, B> class final

The

Inheritance
Available extensions

Constructors

object([A? first, B? second])
const

Properties

attributes Map<String, String>
no setterinherited
children Iterable<Component>
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tag String
no setteroverride

Methods

build() Iterable<Component>
Builds this component's children.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
render([Renderer renderer = const Renderer(), StringBuffer? sb]) String

Available on Component, provided by the RenderComponentExtension extension

Renders this component tree to an XML string using an optional custom Renderer.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited