BArg class
Defines a b:arg attribute with either a static or expression value.
- Inheritance
-
- Object
- DomComponent
- BArg
- Available extensions
Constructors
Properties
-
attributes
→ Map<
String, String> -
no setterinherited
-
children
→ Iterable<
Component> -
no setterinherited
- exprValue → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- name → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- tag → String
-
no setteroverride
- value → String?
-
final
Methods
-
build(
) → Iterable< Component> -
Builds this component's children.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
render(
[Renderer renderer = const Renderer(), StringBuffer? sb]) → String -
Available on Component, provided by the RenderComponentExtension extension
Renders this component tree to an XML string using an optional custom Renderer. -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited