embed<A, B> class
final
The HTML element embeds external content at the specified point in the document. This content is provided by an external application or other source of interactive content such as a browser plug-in.
- Inheritance
-
- Object
- DomComponent<
A, B> - embed
- Available extensions
Constructors
- embed([A? first, B? second])
-
const
Properties
Methods
-
build(
) → Iterable< Component> -
Builds this component's children.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
render(
[Renderer renderer = const Renderer(), StringBuffer? sb]) → String -
Available on Component, provided by the RenderComponentExtension extension
Renders this component tree to an XML string using an optional custom Renderer. -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited