input<A, B> class
final
The HTML element is used to create interactive controls for web-based forms in order to accept data from the user; a wide variety of types of input data and control widgets are available, depending on the device and user agent.
- Inheritance
-
- Object
- DomComponent<
A, B> - input
- Available extensions
Constructors
- input([A? first, B? second])
-
const
Properties
Methods
-
build(
) → Iterable< Component> -
Builds this component's children.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
render(
[Renderer renderer = const Renderer(), StringBuffer? sb]) → String -
Available on Component, provided by the RenderComponentExtension extension
Renders this component tree to an XML string using an optional custom Renderer. -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited